Learn R Programming

redquack (version 0.3.0)

list_to_env: Assign List to Global Environment

Description

Assign a list of instruments (data frames) to the global environment. Each element of the list becomes a separate object in the global environment.

Usage

list_to_env(instruments)

Value

Invisibly returns NULL. Side effect: assigns objects to the global environment.

Arguments

instruments

A named list of data frames, typically output from tbl_to_list().

Examples

Run this code
if (FALSE) {
tbl(conn, "data") |>
  tbl_to_list() |>
  list_to_env()
}

Run the code above in your browser using DataLab