powered by
Assign a list of instruments (data frames) to the global environment. Each element of the list becomes a separate object in the global environment.
list_to_env(instruments)
Invisibly returns NULL. Side effect: assigns objects to the global environment.
A named list of data frames, typically output from tbl_to_list().
if (FALSE) { tbl(conn, "data") |> tbl_to_list() |> list_to_env() }
Run the code above in your browser using DataLab